You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2021/11/12 21:02:31 UTC

[libcloud] branch trunk updated (31c938d -> c4d4df9)

This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a change to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git.


    from 31c938d  Update docs - add note on not supporting Python 3.5 anymore.
     new 926731d  Update verify checksum scripts to also handle wheel files and remove .tar.bz2 check since we haven't been uploading .tar.bz2 files for a while now.
     new 37a2872  Instead of comparing md5 sum, compare sha512 sum instead.
     new c4d4df9  Add additional badges to the readme.

The 3 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 README.rst               | 10 +++++++++-
 dist/verify_checksums.sh | 46 +++++++++++++++++++++++++++++-----------------
 2 files changed, 38 insertions(+), 18 deletions(-)

[libcloud] 03/03: Add additional badges to the readme.

Posted by to...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit c4d4df9d53e638ddf68288080d95c564dec80327
Author: Tomaz Muraus <to...@tomaz.me>
AuthorDate: Fri Nov 12 22:02:21 2021 +0100

    Add additional badges to the readme.
---
 README.rst | 10 +++++++++-
 1 file changed, 9 insertions(+), 1 deletion(-)

diff --git a/README.rst b/README.rst
index 3beab39..3efb26e 100644
--- a/README.rst
+++ b/README.rst
@@ -33,10 +33,18 @@ through a unified and easy to use API.
 .. image:: https://img.shields.io/github/license/apache/libcloud.svg
         :target: https://github.com/apache/libcloud/blob/trunk/LICENSE
 
+.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
+        :target: https://black.readthedocs.io/en/stable/the_black_code_style/current_style.html
+
+.. image:: https://img.shields.io/twitter/follow/Libcloud.svg?style=social&label=Follow
+        :target: https://twitter.com/Libcloud
+
+.. image:: https://img.shields.io/pypi/dm/apache-libcloud
+        :target: https://pypi.org/project/apache-libcloud
+
 .. image:: https://bestpractices.coreinfrastructure.org/projects/152/badge
         :target: https://bestpractices.coreinfrastructure.org/projects/152
 
-
 :Code:          https://github.com/apache/libcloud
 :License:       Apache 2.0; see LICENSE file
 :Issues:        https://issues.apache.org/jira/projects/LIBCLOUD/issues

[libcloud] 02/03: Instead of comparing md5 sum, compare sha512 sum instead.

Posted by to...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit 37a28720142927fef22f9828730fbb1438151139
Author: Tomaz Muraus <to...@tomaz.me>
AuthorDate: Thu Nov 11 21:00:38 2021 +0100

    Instead of comparing md5 sum, compare sha512 sum instead.
---
 dist/verify_checksums.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/dist/verify_checksums.sh b/dist/verify_checksums.sh
index c739dd1..90357b5 100755
--- a/dist/verify_checksums.sh
+++ b/dist/verify_checksums.sh
@@ -19,20 +19,22 @@
 
 VERSION=$1
 
-if [ ! ${VERSION} ]; then
+if [ ! "${VERSION}" ]; then
     echo "Usage: ${0} <version name>"
-    echo "For example: ${0} apache-libcloud-0.13.2"
+    echo "For example: ${0} apache-libcloud-3.4.0"
     exit 1
 fi
 
-TMP_DIR=`mktemp -d`
+TMP_DIR=$(mktemp -d)
 
-EXTENSIONS[0]="tar.gz"
-EXTENSIONS[1]="tar.bz2"
-EXTENSIONS[2]="zip"
+# TODO: Use json endpoint + jq to parse out the url
+# https://pypi.org/pypi/apache-libcloud/3.4.0/json
+EXTENSIONS[0]=".tar.gz"
+EXTENSIONS[1]="-py2.py3-none-any.whl"
 
 APACHE_MIRROR_URL="http://www.apache.org/dist/libcloud"
-PYPI_MIRROR_URL="https://pypi.python.org/packages/source/a/apache-libcloud"
+PYPI_MIRROR_URL_SOURCE="https://pypi.python.org/packages/source/a/apache-libcloud"
+PYPI_MIRROR_URL_WHEEL="https://files.pythonhosted.org/packages/py2.py3/a/apache-libcloud"
 
 # From http://tldp.org/LDP/abs/html/debugging.html#ASSERT
 function assert ()                 #  If condition false,
@@ -49,7 +51,7 @@ function assert ()                 #  If condition false,
 
   lineno=$2
 
-  if [ ! $1 ]
+  if [ ! "$1" ]
   then
     echo "Assertion failed:  \"$1\""
     echo "File \"$0\", line $lineno"    # Give name of file and line number.
@@ -65,11 +67,21 @@ echo ""
 for (( i = 0 ; i < ${#EXTENSIONS[@]} ; i++ ))
 do
     extension=${EXTENSIONS[$i]}
-    file_name="${VERSION}.${extension}"
+    file_name="${VERSION}${extension}"
+
+    if [ "${extension}" = "-py2.py3-none-any.whl" ]; then
+        file_name=$(echo ${file_name} | sed "s/apache-libcloud/apache_libcloud/g")
+    fi
 
     apache_url="${APACHE_MIRROR_URL}/${file_name}"
     pypi_url="${PYPI_MIRROR_URL}/${file_name}"
 
+    if [ "${extension}" = "-py2.py3-none-any.whl" ]; then
+        pypi_url="${PYPI_MIRROR_URL_WHEEL}/${file_name}"
+    else
+        pypi_url="${PYPI_MIRROR_URL_SOURCE}/${file_name}"
+    fi
+
     assert "${apache_url} != ${pypi_url}", "URLs must be different"
 
     file_name_apache="${file_name}-apache"
diff --git a/dist/verify_checksums.sh b/dist/verify_checksums.sh
index 90357b5..c58339b 100755
--- a/dist/verify_checksums.sh
+++ b/dist/verify_checksums.sh
@@ -15,7 +15,7 @@
 # limitations under the license.
 
 # This script downloads release artifacts from Apache server and PyPi server and
 # verifies that the MD5 checksum of both archives matches.
 
 VERSION=$1
 
@@ -110,17 +110,17 @@ do
         exit 2
     fi
 
-    md5sum_apache=$(md5sum "${file_path_apache}" | awk '{ print $1 }')
-    md5sum_pypi=$(md5sum "${file_path_pypi}"| awk '{ print $1 }')
+    sha512sum_apache=$(sha512sum "${file_path_apache}" | awk '{ print $1 }')
+    sha512sum_pypi=$(sha512sum "${file_path_pypi}"| awk '{ print $1 }')
 
-    if [ ${md5sum_apache} != ${md5sum_pypi} ]; then
-       echo "[ERROR] MD5 sum for file ${file_name} doesn\'t match"
+    if [ ${sha512sum_apache} != ${sha512sum_pypi} ]; then
+       echo "[ERROR] SHA512 sum for file ${file_name} doesn\'t match"
        echo ""
-       echo "${file_name_apache}: ${md5sum_apache}"
-       echo "${file_name_pypi}: ${md5sum_pypi}"
+       echo "${file_name_apache}: ${sha512sum_apache}"
+       echo "${file_name_pypi}: ${sha512sum_pypi}"
        exit 1
    else
-       echo "[OK] MD5 sum for file ${file_name} matches"
+       echo "[OK] SHA512 sum for file ${file_name} matches"
     fi
 
     echo ""

[libcloud] 01/03: Update verify checksum scripts to also handle wheel files and remove .tar.bz2 check since we haven't been uploading .tar.bz2 files for a while now.

Posted by to...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit 926731d1877fa76aee248faf635fc6c3c9a1435b
Author: Tomaz Muraus <to...@tomaz.me>
AuthorDate: Thu Nov 11 20:59:36 2021 +0100

    Update verify checksum scripts to also handle wheel files and remove
    .tar.bz2 check since we haven't been uploading .tar.bz2 files for a
    while now.
---
 dist/verify_checksums.sh | 30 +++++++++++++++++++++---------
 1 file changed, 21 insertions(+), 9 deletions(-)
@@ -15,7 +15,7 @@
 
 # This script downloads release artifacts from Apache server and PyPi server and
-# verifies that the MD5 checksum of both archives matches.
+# verifies that the SHA512 checksum of both archives matches.
 
 VERSION=$1
